package dap

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Stopped_event.PayloadSource

Sourcemodule Reason : sig ... end
Sourcetype t = {
  1. reason : Reason.t;
    (*

    The reason for the event. For backward compatibility this string is shown in the UI if the `description` attribute is missing (but it must not be translated).

    *)
  2. description : string option;
    (*

    The full reason for the event, e.g. 'Paused on exception'. This string is shown in the UI as is and can be translated.

    *)
  3. thread_id : int option;
    (*

    The thread which was stopped.

    *)
  4. preserve_focus_hint : bool option;
    (*

    A value of true hints to the client that this event should not change the focus.

    *)
  5. text : string option;
    (*

    Additional information. E.g. if reason is `exception`, text contains the exception name. This string is shown in the UI.

    *)
  6. all_threads_stopped : bool option;
    (*

    If `allThreadsStopped` is true, a debug adapter can announce that all threads have stopped.

    • The client should use this information to enable that all threads can be expanded to access their stacktraces.
    • If the attribute is missing or false, only the thread with the given `threadId` can be expanded.
    *)
  7. hit_breakpoint_ids : int list option;
    (*

    Ids of the breakpoints that triggered the event. In most cases there is only a single breakpoint but here are some examples for multiple breakpoints:

    • Different types of breakpoints map to the same location.
    • Multiple source breakpoints get collapsed to the same instruction by the compiler/runtime.
    • Multiple function breakpoints with different function names map to the same location.
    *)
}
Sourceval make : reason:Reason.t -> ?description:string option -> ?thread_id:int option -> ?preserve_focus_hint:bool option -> ?text:string option -> ?all_threads_stopped:bool option -> ?hit_breakpoint_ids:int list option -> unit -> t
Sourceval to_yojson : t -> Yojson.Safe.t