package dap

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Debug_protocol.Set_variable_commandSource

Set the variable with the given name in the variable container to a new value. Clients should only call this request if the capability 'supportsSetVariable' is true.

Sourceval type_ : string
Sourcemodule Arguments : sig ... end
Sourcemodule Result : sig ... end